==> ejc-riskmortgage-impl-3.0.0-20220712.115902-59-sources.jar: com/ejianc/business/standard/bean/StandardEntity.java <==
package com.ejianc.business.standard.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.standard.bean.StandardDetailEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 风险金缴纳标准表主实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_standard")
public class StandardEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="org_id")
    private Long orgId; // 申请组织Id
    @TableField(value="org_name")
    private String orgName; // 申请组织名称
    @TableField(value="org_code")
    private String orgCode; // 申请组织编码
    @TableField(value="last_year_contract_mny")
    private BigDecimal lastYearContractMny; // 上一年度完成合同额
    @TableField(value="last_year_output_mny")
    private BigDecimal lastYearOutputMny; // 上一年度产值
    @TableField(value="worker_congress_contract_mny")
    private BigDecimal workerCongressContractMny; // 本年度职代会合同金额
    @TableField(value="output_mny")
    private BigDecimal outputMny; // 本年度产值
    @TableField(value="belong_year")
    @JsonFormat(pattern = "yyyy", timezone = "GMT+8")
    private Date belongYear; // 所属年度
    @TableField(value="risk_deposit_payable_scale")
    private BigDecimal riskDepositPayableScale; // 风险金应缴纳比例
    @TableField(value="risk_deposit_payable_mny")
    private BigDecimal riskDepositPayableMny; // 风险金应缴纳金额(本年度职代会合同金额*应缴纳比例)
    @TableField(value="risk_deposit_mny")
    private BigDecimal riskDepositMny; // 风险金申请缴纳金额
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id（申请人）
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称（申请人）
    @TableField(value="department_id")
    private Long departmentId; // 经办人部门id
    @TableField(value="department_name")
    private String departmentName; // 经办人部门
    @TableField(value="apply_reason")
    private String applyReason; // 申请事由
    @TableField(value="effect_date")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date effectDate; // 生效日期
    @TableField(value="change_code")
    private String changeCode; // 变更单号
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_status")
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @TableField(value="change_date")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date changeDate; // 变更日期
    @TableField(value="before_change_risk_deposit_mny")
    private BigDecimal beforeChangeRiskDepositMny; // 变更前缴纳金额
    @TableField(value="changing_risk_deposit_mny")
    private BigDecimal changingRiskDepositMny; // 变更中缴纳金额
    @TableField(value="direct_risk_deposit_id")
    private Long directRiskDepositId; // 直管部风险保证金id（用于数据引用）
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_code")
    private String contractCode; // 合同编码
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同金额
    @TableField(value="contract_sign_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date contractSignDate; // 合同签订日期
    @TableField(value="risk_deposit_type")
    private String riskDepositType; // 风险保证金类型(directDept-直管部、projectDept-项目部)
    @TableField("base_mny")
    private BigDecimal baseMny; //初始版本金额
    @TableField(value="change_employee_id")
    private Long changeEmployeeId; // 变更经办人id
    @TableField(value="change_employee_name")
    private String changeEmployeeName; // 变更经办人名称
    @TableField(value="change_effect_date")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date changeEffectDate; // 变更生效日期


    @TableField(value="project_parent_org_id")
    private Long projectParentOrgId; //所属项目父组织Id
    @TableField(value="project_parent_org_name")
    private String projectParentOrgName; //所属项目父组织名称
    @TableField(value="project_parent_org_code")
    private String projectParentOrgCode; //所属项目父组织编码
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="standardDetailService", pidName = "standardId")//此处有pid="xxx"，默认值pid="pid"
    private List<StandardDetailEntity> detailList = new ArrayList<>(); // 风险金缴纳标准表子实体
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public BigDecimal getLastYearContractMny() {
        return lastYearContractMny;
    }

    public void setLastYearContractMny(BigDecimal lastYearContractMny) {
        this.lastYearContractMny = lastYearContractMny;
    }
    public BigDecimal getLastYearOutputMny() {
        return lastYearOutputMny;
    }

    public void setLastYearOutputMny(BigDecimal lastYearOutputMny) {
        this.lastYearOutputMny = lastYearOutputMny;
    }
    public BigDecimal getWorkerCongressContractMny() {
        return workerCongressContractMny;
    }

    public void setWorkerCongressContractMny(BigDecimal workerCongressContractMny) {
        this.workerCongressContractMny = workerCongressContractMny;
    }
    public BigDecimal getOutputMny() {
        return outputMny;
    }

    public void setOutputMny(BigDecimal outputMny) {
        this.outputMny = outputMny;
    }
    public Date getBelongYear() {
        return belongYear;
    }

    public void setBelongYear(Date belongYear) {
        this.belongYear = belongYear;
    }
    public BigDecimal getRiskDepositPayableScale() {
        return riskDepositPayableScale;
    }

    public void setRiskDepositPayableScale(BigDecimal riskDepositPayableScale) {
        this.riskDepositPayableScale = riskDepositPayableScale;
    }
    public BigDecimal getRiskDepositPayableMny() {
        return riskDepositPayableMny;
    }

    public void setRiskDepositPayableMny(BigDecimal riskDepositPayableMny) {
        this.riskDepositPayableMny = riskDepositPayableMny;
    }
    public BigDecimal getRiskDepositMny() {
        return riskDepositMny;
    }

    public void setRiskDepositMny(BigDecimal riskDepositMny) {
        this.riskDepositMny = riskDepositMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }
    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }
    public String getChangeCode() {
        return changeCode;
    }

    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    public Date getChangeDate() {
        return changeDate;
    }

    public void setChangeDate(Date changeDate) {
        this.changeDate = changeDate;
    }
    public BigDecimal getBeforeChangeRiskDepositMny() {
        return beforeChangeRiskDepositMny;
    }

    public void setBeforeChangeRiskDepositMny(BigDecimal beforeChangeRiskDepositMny) {
        this.beforeChangeRiskDepositMny = beforeChangeRiskDepositMny;
    }
    public BigDecimal getChangingRiskDepositMny() {
        return changingRiskDepositMny;
    }

    public void setChangingRiskDepositMny(BigDecimal changingRiskDepositMny) {
        this.changingRiskDepositMny = changingRiskDepositMny;
    }
    public Long getDirectRiskDepositId() {
        return directRiskDepositId;
    }

    public void setDirectRiskDepositId(Long directRiskDepositId) {
        this.directRiskDepositId = directRiskDepositId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }
    public Date getContractSignDate() {
        return contractSignDate;
    }

    public void setContractSignDate(Date contractSignDate) {
        this.contractSignDate = contractSignDate;
    }
    public String getRiskDepositType() {
        return riskDepositType;
    }

    public void setRiskDepositType(String riskDepositType) {
        this.riskDepositType = riskDepositType;
    }

    public List<StandardDetailEntity> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<StandardDetailEntity> detailList) {
        this.detailList = detailList;
    }

    public BigDecimal getBaseMny() {
        return baseMny;
    }

    public void setBaseMny(BigDecimal baseMny) {
        this.baseMny = baseMny;
    }

    public Long getChangeEmployeeId() {
        return changeEmployeeId;
    }

    public void setChangeEmployeeId(Long changeEmployeeId) {
        this.changeEmployeeId = changeEmployeeId;
    }

    public String getChangeEmployeeName() {
        return changeEmployeeName;
    }

    public void setChangeEmployeeName(String changeEmployeeName) {
        this.changeEmployeeName = changeEmployeeName;
    }

    public Date getChangeEffectDate() {
        return changeEffectDate;
    }

    public void setChangeEffectDate(Date changeEffectDate) {
        this.changeEffectDate = changeEffectDate;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectParentOrgId() {
        return projectParentOrgId;
    }

    public void setProjectParentOrgId(Long projectParentOrgId) {
        this.projectParentOrgId = projectParentOrgId;
    }

    public String getProjectParentOrgName() {
        return projectParentOrgName;
    }

    public void setProjectParentOrgName(String projectParentOrgName) {
        this.projectParentOrgName = projectParentOrgName;
    }

    public String getProjectParentOrgCode() {
        return projectParentOrgCode;
    }

    public void setProjectParentOrgCode(String projectParentOrgCode) {
        this.projectParentOrgCode = projectParentOrgCode;
    }
}

==> ejc-riskmortgage-impl-3.0.0-20251013.062427-130-sources.jar: com/ejianc/business/standard/bean/StandardEntity.java <==
package com.ejianc.business.standard.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.standard.bean.StandardDetailEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 风险金缴纳标准表主实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_standard")
public class StandardEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="org_id")
    private Long orgId; // 申请组织Id
    @TableField(value="org_name")
    private String orgName; // 申请组织名称
    @TableField(value="org_code")
    private String orgCode; // 申请组织编码
    @TableField(value="last_year_contract_mny")
    private BigDecimal lastYearContractMny; // 上一年度完成合同额
    @TableField(value="last_year_output_mny")
    private BigDecimal lastYearOutputMny; // 上一年度产值
    @TableField(value="worker_congress_contract_mny")
    private BigDecimal workerCongressContractMny; // 本年度职代会合同金额
    @TableField(value="output_mny")
    private BigDecimal outputMny; // 本年度产值
    @TableField(value="belong_year")
    @JsonFormat(pattern = "yyyy", timezone = "GMT+8")
    private Date belongYear; // 所属年度
    @TableField(value="risk_deposit_payable_scale")
    private BigDecimal riskDepositPayableScale; // 风险金应缴纳比例
    @TableField(value="risk_deposit_payable_mny")
    private BigDecimal riskDepositPayableMny; // 风险金应缴纳金额(本年度职代会合同金额*应缴纳比例)
    @TableField(value="risk_deposit_mny")
    private BigDecimal riskDepositMny; // 风险金申请缴纳金额
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id（申请人）
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称（申请人）
    @TableField(value="department_id")
    private Long departmentId; // 经办人部门id
    @TableField(value="department_name")
    private String departmentName; // 经办人部门
    @TableField(value="apply_reason")
    private String applyReason; // 申请事由
    @TableField(value="effect_date")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date effectDate; // 生效日期
    @TableField(value="change_code")
    private String changeCode; // 变更单号
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_status")
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @TableField(value="change_date")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date changeDate; // 变更日期
    @TableField(value="before_change_risk_deposit_mny")
    private BigDecimal beforeChangeRiskDepositMny; // 变更前缴纳金额
    @TableField(value="changing_risk_deposit_mny")
    private BigDecimal changingRiskDepositMny; // 变更中缴纳金额
    @TableField(value="direct_risk_deposit_id")
    private Long directRiskDepositId; // 直管部风险保证金id（用于数据引用）
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_code")
    private String contractCode; // 合同编码
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同金额
    @TableField(value="contract_sign_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date contractSignDate; // 合同签订日期
    @TableField(value="risk_deposit_type")
    private String riskDepositType; // 风险保证金类型(directDept-直管部、projectDept-项目部)
    @TableField("base_mny")
    private BigDecimal baseMny; //初始版本金额
    @TableField(value="change_employee_id")
    private Long changeEmployeeId; // 变更经办人id
    @TableField(value="change_employee_name")
    private String changeEmployeeName; // 变更经办人名称
    @TableField(value="change_effect_date")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date changeEffectDate; // 变更生效日期
    @TableField(value="memo")
    private String memo; // 备注


    @TableField(value="project_parent_org_id")
    private Long projectParentOrgId; //所属项目父组织Id
    @TableField(value="project_parent_org_name")
    private String projectParentOrgName; //所属项目父组织名称
    @TableField(value="project_parent_org_code")
    private String projectParentOrgCode; //所属项目父组织编码
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="standardDetailService", pidName = "standardId")//此处有pid="xxx"，默认值pid="pid"
    private List<StandardDetailEntity> detailList = new ArrayList<>(); // 风险金缴纳标准表子实体
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public BigDecimal getLastYearContractMny() {
        return lastYearContractMny;
    }

    public void setLastYearContractMny(BigDecimal lastYearContractMny) {
        this.lastYearContractMny = lastYearContractMny;
    }
    public BigDecimal getLastYearOutputMny() {
        return lastYearOutputMny;
    }

    public void setLastYearOutputMny(BigDecimal lastYearOutputMny) {
        this.lastYearOutputMny = lastYearOutputMny;
    }
    public BigDecimal getWorkerCongressContractMny() {
        return workerCongressContractMny;
    }

    public void setWorkerCongressContractMny(BigDecimal workerCongressContractMny) {
        this.workerCongressContractMny = workerCongressContractMny;
    }
    public BigDecimal getOutputMny() {
        return outputMny;
    }

    public void setOutputMny(BigDecimal outputMny) {
        this.outputMny = outputMny;
    }
    public Date getBelongYear() {
        return belongYear;
    }

    public void setBelongYear(Date belongYear) {
        this.belongYear = belongYear;
    }
    public BigDecimal getRiskDepositPayableScale() {
        return riskDepositPayableScale;
    }

    public void setRiskDepositPayableScale(BigDecimal riskDepositPayableScale) {
        this.riskDepositPayableScale = riskDepositPayableScale;
    }
    public BigDecimal getRiskDepositPayableMny() {
        return riskDepositPayableMny;
    }

    public void setRiskDepositPayableMny(BigDecimal riskDepositPayableMny) {
        this.riskDepositPayableMny = riskDepositPayableMny;
    }
    public BigDecimal getRiskDepositMny() {
        return riskDepositMny;
    }

    public void setRiskDepositMny(BigDecimal riskDepositMny) {
        this.riskDepositMny = riskDepositMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }
    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }
    public String getChangeCode() {
        return changeCode;
    }

    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    public Date getChangeDate() {
        return changeDate;
    }

    public void setChangeDate(Date changeDate) {
        this.changeDate = changeDate;
    }
    public BigDecimal getBeforeChangeRiskDepositMny() {
        return beforeChangeRiskDepositMny;
    }

    public void setBeforeChangeRiskDepositMny(BigDecimal beforeChangeRiskDepositMny) {
        this.beforeChangeRiskDepositMny = beforeChangeRiskDepositMny;
    }
    public BigDecimal getChangingRiskDepositMny() {
        return changingRiskDepositMny;
    }

    public void setChangingRiskDepositMny(BigDecimal changingRiskDepositMny) {
        this.changingRiskDepositMny = changingRiskDepositMny;
    }
    public Long getDirectRiskDepositId() {
        return directRiskDepositId;
    }

    public void setDirectRiskDepositId(Long directRiskDepositId) {
        this.directRiskDepositId = directRiskDepositId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }
    public Date getContractSignDate() {
        return contractSignDate;
    }

    public void setContractSignDate(Date contractSignDate) {
        this.contractSignDate = contractSignDate;
    }
    public String getRiskDepositType() {
        return riskDepositType;
    }

    public void setRiskDepositType(String riskDepositType) {
        this.riskDepositType = riskDepositType;
    }

    public List<StandardDetailEntity> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<StandardDetailEntity> detailList) {
        this.detailList = detailList;
    }

    public BigDecimal getBaseMny() {
        return baseMny;
    }

    public void setBaseMny(BigDecimal baseMny) {
        this.baseMny = baseMny;
    }

    public Long getChangeEmployeeId() {
        return changeEmployeeId;
    }

    public void setChangeEmployeeId(Long changeEmployeeId) {
        this.changeEmployeeId = changeEmployeeId;
    }

    public String getChangeEmployeeName() {
        return changeEmployeeName;
    }

    public void setChangeEmployeeName(String changeEmployeeName) {
        this.changeEmployeeName = changeEmployeeName;
    }

    public Date getChangeEffectDate() {
        return changeEffectDate;
    }

    public void setChangeEffectDate(Date changeEffectDate) {
        this.changeEffectDate = changeEffectDate;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectParentOrgId() {
        return projectParentOrgId;
    }

    public void setProjectParentOrgId(Long projectParentOrgId) {
        this.projectParentOrgId = projectParentOrgId;
    }

    public String getProjectParentOrgName() {
        return projectParentOrgName;
    }

    public void setProjectParentOrgName(String projectParentOrgName) {
        this.projectParentOrgName = projectParentOrgName;
    }

    public String getProjectParentOrgCode() {
        return projectParentOrgCode;
    }

    public void setProjectParentOrgCode(String projectParentOrgCode) {
        this.projectParentOrgCode = projectParentOrgCode;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}
